@@ -70,8 +70,6 @@ Options:
 """
 
 import os, sys
-sys.path.append('/Users/drorrusso/opereto/pyopereto')
-
 import uuid
 import shutil
 import yaml
@@ -154,14 +152,8 @@ with open(opereto_config_file, 'r') as f:
 OPERETO_HOST = opereto_credentials_json['opereto_host']
 print('Opereto cluster: {}'.format(OPERETO_HOST))
 def get_opereto_client():
-    if opereto_credentials_json.get('opereto_password'):
-        client = OperetoClient(opereto_host=OPERETO_HOST,
-                               opereto_user=opereto_credentials_json['opereto_user'],
-                               opereto_password=opereto_credentials_json['opereto_password'])
-        return client
-    else:
-        client = OperetoClient(opereto_host=OPERETO_HOST, opereto_token=opereto_credentials_json['opereto_token'])
-        return client
+    client = OperetoClient(opereto_host=OPERETO_HOST, opereto_token=opereto_credentials_json['opereto_token'])
+    return client
 
 
 def print_token(params):
